summaryrefslogtreecommitdiffstats
path: root/webkit/appcache
diff options
context:
space:
mode:
authorbrettw@chromium.org <brettw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-03-29 19:21:31 +0000
committerbrettw@chromium.org <brettw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-03-29 19:21:31 +0000
commit8275835e508fb36328dd79c338d31bbf98eadf56 (patch)
treef78d6d976f6bad03de09a82d550943068db096a3 /webkit/appcache
parent460d2fd0876fddb9e6a2a17cba9c70beb93dfa03 (diff)
downloadchromium_src-8275835e508fb36328dd79c338d31bbf98eadf56.zip
chromium_src-8275835e508fb36328dd79c338d31bbf98eadf56.tar.gz
chromium_src-8275835e508fb36328dd79c338d31bbf98eadf56.tar.bz2
Replace string16 with base::string16 in src/webkit
BUG= Review URL: https://codereview.chromium.org/13219005 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@191421 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'webkit/appcache')
-rw-r--r--webkit/appcache/manifest_parser.cc12
1 files changed, 6 insertions, 6 deletions
diff --git a/webkit/appcache/manifest_parser.cc b/webkit/appcache/manifest_parser.cc
index eb16d8b..0d98d1e 100644
--- a/webkit/appcache/manifest_parser.cc
+++ b/webkit/appcache/manifest_parser.cc
@@ -57,7 +57,7 @@ bool ParseManifest(const GURL& manifest_url, const char* data, int length,
// http://www.w3.org/TR/html5/offline.html
// Do not modify it without consulting those docs.
// Though you might be tempted to convert these wstrings to UTF-8 or
// string16, this implementation seems simpler given the constraints.
const wchar_t kSignature[] = L"CACHE MANIFEST";
const size_t kSignatureLength = arraysize(kSignature) - 1;
@@ -162,7 +162,7 @@ bool ParseManifest(const GURL& manifest_url, const char* data, int length,
while (line_p < line_end && *line_p != '\t' && *line_p != ' ')
++line_p;
- string16 url16;
+ base::string16 url16;
WideToUTF16(line.c_str(), line_p - line.c_str(), &url16);
GURL url = manifest_url.Resolve(url16);
if (!url.is_valid())
@@ -205,7 +205,7 @@ bool ParseManifest(const GURL& manifest_url, const char* data, int length,
if (line_p == line_end)
continue; // There was no whitespace separating the URLs.
- string16 namespace_url16;
+ base::string16 namespace_url16;
WideToUTF16(line.c_str(), line_p - line.c_str(), &namespace_url16);
GURL namespace_url = manifest_url.Resolve(namespace_url16);
if (!namespace_url.is_valid())
@@ -244,7 +244,7 @@ bool ParseManifest(const GURL& manifest_url, const char* data, int length,
while (line_p < line_end && *line_p != '\t' && *line_p != ' ')
++line_p;
- string16 target_url16;
+ base::string16 target_url16;
WideToUTF16(target_url_start, line_p - target_url_start, &target_url16);
GURL target_url = manifest_url.Resolve(target_url16);
if (!target_url.is_valid())
@@ -273,7 +273,7 @@ bool ParseManifest(const GURL& manifest_url, const char* data, int length,
continue;
}
- string16 namespace_url16;
+ base::string16 namespace_url16;
WideToUTF16(line.c_str(), line_p - line.c_str(), &namespace_url16);
GURL namespace_url = manifest_url.Resolve(namespace_url16);
if (!namespace_url.is_valid())
@@ -299,7 +299,7 @@ bool ParseManifest(const GURL& manifest_url, const char* data, int length,
while (line_p < line_end && *line_p != '\t' && *line_p != ' ')
++line_p;
- string16 fallback_url16;
+ base::string16 fallback_url16;
WideToUTF16(fallback_start, line_p - fallback_start, &fallback_url16);
GURL fallback_url = manifest_url.Resolve(fallback_url16);
if (!fallback_url.is_valid())
@@ -57,7 +57,7 @@ bool ParseManifest(const GURL& manifest_url, const char* data, int length,
// Do not modify it without consulting those docs.
// Though you might be tempted to convert these wstrings to UTF-8 or
- // string16, this implementation seems simpler given the constraints.
+ // base::string16, this implementation seems simpler given the constraints.
const wchar_t kSignature[] = L"CACHE MANIFEST";
const size_t kSignatureLength = arraysize(kSignature) - 1;